# PageOn

The list of items to page on when fetching the next page. These should be copied verbatim into the next query, since the API may have added an extra value to the keys in order to tie-break. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**value** | **[str]** | The list of items to page on when fetching the next page. These should be copied verbatim into the next query, since the API may have added an extra value to the keys in order to tie-break.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


